@@ -5,25 +5,25 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.13_03';
+our $VERSION = '0.14_01';
 $VERSION =~ tr/_//d;
 
 use Carp qw(verbose);    # makes carp() cluck and croak() confess
 
 sub _warn {
-  if ($_[-1] =~ /\n$/s) {
+  if ($_[-1] =~ /\n\z/) {
     my $arg = pop @_;
-    $arg =~ s/(.*)( at .*? line .*?\n$)/$1/s;
+    $arg =~ s/(.*) at [^\n]*? line [0-9]+\.?\n$/$1/s;
     push @_, $arg;
   }
   warn &Carp::longmess;
 }
 
 sub _die {
-  die @_ if ref($_[0]);
-  if ($_[-1] =~ /\n$/s) {
+  die @_ if ref $_[0];
+  if ($_[-1] =~ /\n\z/) {
     my $arg = pop @_;
-    $arg =~ s/(.*)( at .*? line .*?\n$)/$1/s;
+    $arg =~ s/(.*) at [^\n]*? line [0-9]+\.?\n$/$1/s;
     push @_, $arg;
   }
   die &Carp::longmess;
@@ -126,8 +126,8 @@ L<Devel::Confess>
 =item *
 
 This module does not play well with other modules which fusses
-around with C<warn>, C<die>, C<$SIG{'__WARN__'}>,
-C<$SIG{'__DIE__'}>.
+around with C<warn>, C<die>, C<$SIG{__WARN__}>,
+C<$SIG{__DIE__}>.
 
 =item *
 
